%GSP_DEMO3_VERTEX_FREQUENCY
%
%   Url: http://gspbox.sourceforge.net/doc/demo/gsp_demo3_vertex_frequency.php

% Copyright (C) 2013 David I Shuman, Nathanael Perraudin.
% This file is part of GSPbox version 0.0.1
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.

close all;
clear all; 
set(0,'DefaultFigureWindowStyle','docked');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Set up graph 
randn('seed', 18); rand('seed', 18);
G=gsp_create_graph('minnesota');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Generate the signal (which requires full eigendecomposition)
G=gsp_full_eigen(G);

% Perform spectral clustering
num_clusters=5;
current_clusters=kmeans(G.U(:,1:num_clusters),num_clusters);

% Plot clusters
cluster_colors=['g','b','r','k','m'];
clustering_param.num_clusters=num_clusters;
clustering_param.clusters=current_clusters;
clustering_param.cluster_colors=cluster_colors;
gsp_plot_graph(G,clustering_param);

% Construct and plot a signal to analyze
% (by summing different eigenvectors restricted to different clusters of the graph)
lower_bounds=[0.06,0.3,3.2,6.0,4.6];
upper_bounds=[0.08,0.5,3.7,6.6,5.0];
signal=zeros(G.N,1);
for i=1:num_clusters
    cluster_signal_hat=(G.E>=lower_bounds(i)).*(G.E<=upper_bounds(i));
    cluster_signal=gsp_igft(cluster_signal_hat,G.U).*(current_clusters==i);
    cluster_signal=cluster_signal/norm(cluster_signal,Inf);
    signal=signal+cluster_signal;
end
gsp_plot_graph_signal(G,signal);
colorbar('Location','SouthOutside');

% Plot the signal in the graph spectral domain
signal_hat=gsp_gft(signal,G.U);
gsp_plot_graph_signal_spectral(G.E,signal_hat);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compute and plot spectral cdf approximation
G=gsp_spectrum_cdf_approx(G);
gsp_plot_warp_fn(G.spectral_warp_fn,[0,G.lmax]);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compute and plot spectrum-adapted Gabor filters
num_filters=15;
warp_approx_param.warp_function_type='custom';
warp_approx_param.warp_function=G.spectral_warp_fn;
warp_approx_param.upper_bound_translates=1;
[warp_approx_filters,warp_approx_function]=gsp_filter_design('warped_translates',num_filters,G.lmax,warp_approx_param);

%warp_approx_param.lambda_full=G.E;
warp_approx_param.lambda_highlights=[0,G.lmax];
[~,warp_approx_test_sum]=gsp_plot_filters(warp_approx_filters,G.lmax,warp_approx_param);
warp_approx_frame_bounds=[min(warp_approx_test_sum),max(warp_approx_test_sum)]

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Analyze signal
analysis_param.use_exact=0;
coeffs=gsp_translates_analysis(G,warp_approx_filters,signal,analysis_param);

% Plot coefficients
max_abs_coeff=max(max(abs(coeffs)));
coeff_param.climits=[-max_abs_coeff,max_abs_coeff];
coeff_param.use_colorbar=0;
coeff_param.pt_size=400;
for k=1:num_filters
        gsp_plot_graph_signal(G,abs(coeffs(:,k)),coeff_param);
        titleStr2=sprintf('%d',k);
        titleStr1='$\left|\langle f,g_{:,';
        titleStr3='} \rangle \right|~~~~~~~~~~~~~$';
        titleStr=[titleStr1,titleStr2,titleStr3];
        title(titleStr,'Interpreter','latex','FontSize',24);
end

