function [G]=gsp_create_comet_graph(N,k)
%GSP_CREATE_COMET_GRAPH  Initialize a comet graph
%   Usage:  G=gsp_create_comet_graph(N,k);
%
%   Input parameters:
%         N     : Number of vertices.
%         k     : Degree of center vertex.
%   Output parameters:
%         G     : Graph structure.
%
%   'gsp_create_comet_graph(N)' initializes a graph structure containing
%   the weighted adjacency matrix (G.W), the number of vertices (G.N), the 
%   plotting coordinates (G.coords), and the plotting coordinate limits 
%   (G.coord_limits) of a comet graph with N vertices, with the central 
%   vertex of the comet having degree k. The edge weights are all equal to 1.
%
%
%   Url: http://gspbox.sourceforge.net/doc/graphs/specific_graphs/gsp_create_comet_graph.php

% Copyright (C) 2013 David I Shuman, Nathanael Perraudin.
% This file is part of GSPbox version 0.0.1
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.

%   AUTHOR : David I Shuman.
%   TESTING: 
%   REFERENCE: 

G.N=N;

% Create weighted adjancency matrix
i_inds=[ones(1,k),2:k+1,k+1:N-1,k+2:N];
j_inds=[2:k+1,ones(1,k),k+2:N,k+1:N-1];
G.W=sparse(i_inds,j_inds,ones(1,length(i_inds)),N,N);

% Create coordinates
G.coords=zeros(N,2);
inds=(2:k+1)';
G.coords(2:k+1,:)=[cos((inds-1)*2*pi/k),sin((inds-1)*2*pi/k)];
G.coords(k+2:end,1)=(2:N-k)';
G.coord_limits=[-2,-2;max(G.coords(:,1)),max(G.coords(:,2))];

