function [G]=gsp_create_erdos_renyi(N,p)
%GSP_CREATE_ERDOS_RENYI  Initialize a random Erdos-Renyi graph
%   Usage:  G=gsp_create_erdos_renyi(N,p);
%
%   Input parameters:
%         N     : Number of vertices.
%         p     : Probability of each edge existing.
%   Output parameters:
%         G     : Graph structure.
%
%   'gsp_create_erdos_renyi(N,p)' initializes a graph structure containing
%   the weighted adjacency matrix (G.W) and the number of vertices (G.N) of 
%   a random Erdos-Renyi graph with N vertices. There is an edge 
%   connecting any two vertices with probability p, independent of all 
%   other edges.  All edge weights are equal to 1. We expect the graph to 
%   be connected when p is close to log(N)/N and we expect a giant 
%   component with log(N) vertices when p is close to 1/(N-1). 
%
%   Requires: 
%
%   Url: http://gspbox.sourceforge.net/doc/graphs/specific_graphs/gsp_create_erdos_renyi.php

% Copyright (C) 2013 David I Shuman, Nathanael Perraudin.
% This file is part of GSPbox version 0.0.1
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.

%   AUTHOR : David I Shuman.
%   TESTING: 
%   REFERENCE: 

randn('seed', 18); rand('seed', 18);

G.N=N;
G.W = rand(G.N,G.N) < p; 
G.W = sparse(G.W);
G.W = triu(G.W,1); 
G.W = G.W + G.W'; 

