function [G]=gsp_create_low_stretch_tree(k)
%GSP_CREATE_LOW_STRETCH_TREE  Initialize a low stretch tree
%   Usage:  G=gsp_create_low_stretch_tree(k);
%
%   Input parameters:
%         k     : 2^k points on each side of the grid of vertices.
%   Output parameters:
%         G     : Graph structure.
%
%   'gsp_create_low_stretch_tree(k)' initializes a graph structure containing
%   the weighted adjacency matrix (G.W), the number of vertices (G.N), the 
%   plotting coordinates (G.coords), the plotting coordinate limits 
%   (G.coord_limits), and the root of a low stretch tree on a grid of points.
%   There are 2^k points on each side of the grid, and therefore 2^{2k} 
%   total vertices. The edge weights are all equal to 1.
%
%
%   Url: http://gspbox.sourceforge.net/doc/graphs/specific_graphs/gsp_create_low_stretch_tree.php

% Copyright (C) 2013 David I Shuman, Nathanael Perraudin.
% This file is part of GSPbox version 0.0.1
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.

%   AUTHOR : David I Shuman.
%   TESTING: 
%   REFERENCE: 

start_nodes=[1,1,3];
end_nodes=[2,3,4];
W=sparse(start_nodes,end_nodes,ones(1,3),4,4);
W=W+W';
XCoords=[1,2,1,2];
YCoords=[1,1,2,2];
for p=2:k
    [ii,jj,~]=find(W);
    ii=ii';
    jj=jj';
    ii_new=[ii,ii+4^(p-1),ii+2*4^(p-1),ii+3*4^(p-1)];
    ii_new_middle=[4^(p-1),4^(p-1),4^(p-1)+(4^p+2)/3,5/3*4^(p-1)+1/3,4^(p-1)+(4^p+2)/3,3*4^(p-1)+1];
    ii_new_all=[ii_new,ii_new_middle];
    jj_new=[jj,jj+4^(p-1),jj+2*4^(p-1),jj+3*4^(p-1)]; 
    jj_new_middle=[5/3*4^(p-1)+1/3,4^(p-1)+(4^p+2)/3,3*4^(p-1)+1,4^(p-1),4^(p-1),4^(p-1)+(4^p+2)/3];
    jj_new_all=[jj_new,jj_new_middle];
    ww_new=ones(size(ii_new_all));
    W=sparse(ii_new_all,jj_new_all,ww_new);
    YCoords=repmat(YCoords,1,2);
    YCoords_new=[YCoords,YCoords+2^(p-1)];
    YCoords=YCoords_new;
    XCoords_new=[XCoords,XCoords+2^(p-1)];
    XCoords=repmat(XCoords_new,1,2);
end
G.coords=[XCoords',YCoords'];
G.coord_limits=[0,0;2^k+1,2^k+1];
G.N=(2^k)^2;
G.W=W;
G.root=4^(k-1);
G.edge_width=1.25;
G.vertex_size=75;

