function [G]=gsp_create_swiss_roll(N,s,thresh,rand_state)
%GSP_CREATE_SWISS_ROLL Initialize a swiss roll graph
%   Usage:  G=gsp_create_swiss_roll(N,s,thresh,rand_state);
%
%   Input parameters:
%         N          : Number of vertices.
%         s          :
%         thresh     :
%         rand_state : 
%   Output parameters:
%         G     : Graph structure.
%
%   'gsp_create_swiss_roll(N,s,thresh,rand_state)' initializes a graph structure containing
%   the weighted adjacency matrix (G.W), the number of vertices (G.N), the 
%   plotting coordinates (G.coords), and the plotting coordinate limits 
%   (G.coord_limits) of a random sensor network with N vertices. The 
%   sensors are placed randomly in the unit square, and edges are placed 
%   between any sensors within a fixed radius of each other. The edge 
%   weights are assigned via a thresholded Gaussian kernel. The sensor 
%   network will be connected for N=500 or N=64. 
%
%   Requires: distanz
%
%   Url: http://gspbox.sourceforge.net/doc/graphs/specific_graphs/gsp_create_swiss_roll.php

% Copyright (C) 2013 David I Shuman, Nathanael Perraudin.
% This file is part of GSPbox version 0.0.1
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.

%   AUTHOR : David I Shuman.
%   TESTING: 
%   REFERENCE: 

G.N=N;

dataparams=struct('n',N,'dataset',-1','noise',0,'state',rand_state); % state was 0 before - 45 now
r=create_synthetic_dataset(dataparams);
G.coords=rescale_center(r.x); % r.x is a 3 x N matrix with the rows equal to the X, Y, and, Z components
G.coords=G.coords';
G.coord_limits = [-1,-1,-1;1,1,1];
dist=distanz(G.coords');
G.W=exp(-dist.^2/(2*s^2));
G.W(G.W<thresh)=0;



