function gsp_plot_graph_signal_spectral(E,f_hat,varargin)
%GSP_PLOT_GRAPH_SIGNAL_SPECTRAL  Plot a graph signal in the graph spectral domain
%   Usage:  gsp_plot_graph_spectral(E,signal);
%           gsp_plot_graph_spectral(E,signal,param);
%
%   Input parameters:
%         E          : Graph Laplacian eigenvalues.
%         f_hat      : Graph signal in the spectral domain.
%         param      : Optional variable containing additional parameters.
%   Output parameters:
%         none
%
%   Additional parameters:
%         param.spectral_highlight     : Highlight one frequency component.
%         param.spectral_plot_abs      : Option to plot the absolute value of f_hat
%
%   'gsp_plot_graph_spectral(E,signal)' plots a graph signal in the graph Fourier domain.
%
%   See also:  
%
%   Demos:  
%
%   Url: http://gspbox.sourceforge.net/doc/plotting/gsp_plot_graph_signal_spectral.php

% Copyright (C) 2013 David I Shuman, Nathanael Perraudin.
% This file is part of GSPbox version 0.0.1
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.

%   AUTHOR : David I Shuman.
%   TESTING: 
%   REFERENCE:
  
% Read input parameters
if nargin>2
    param=varargin{1};
else
    param=0;
end

if isfield(param, 'spectral_highlight')
    highlight=param.spectral_highlight;
else
    highlight=0;
end

if isfield(param, 'spectral_plot_abs')
    spectral_plot_abs=param.spectral_plot_abs;
    if spectral_plot_abs
        f_hat=abs(f_hat);
    end
end

figure;
hold on;
stem(E,f_hat,'LineWidth',5)
if highlight>0
    stem(E(highlight),f_hat(highlight),'filled','r','LineWidth',5);
end
tic_int=ceil(max(E)/10);
set(gca,'XTick',0:tic_int:ceil(max(E)));
set(gca,'color','none')
axis([-.1 ceil(max(E)) 1.1*min(f_hat) max(1.1*max(f_hat),1.1*min(f_hat)+eps)]);
set(gca,'fontsize',24)
box on;
end
